cython: C-Extensions for Python, an optimizing static compiler
==============================================================

Description
-----------

Cython is a language that makes writing C extensions for the Python
language as easy as Python itself. Cython is based on the well-known
Pyrex, but supports more cutting edge functionality and optimizations.

The Cython language is very close to the Python language, but Cython
additio- nally supports calling C functions and declaring C types on
variables and class attributes. This allows the compiler to generate
very efficient C code from Cython code.

This makes Cython the ideal language for wrapping for external C
libraries, and for fast C modules that speed up the execution of Python
code.


License
-------

Apache License, Version 2.0


Upstream Contact
----------------

-  http://www.cython.org/

-  cython-devel@python.org
